==> cgal_3.2.1.orig.tar.gz: CGAL-3.2.1/include/CGAL/Segment_Delaunay_graph_2/Predicates_C2.h <==
// Copyright (c) 2003,2004,2005  INRIA Sophia-Antipolis (France) and
// Notre Dame University (U.S.A.).  All rights reserved.
//
// This file is part of CGAL (www.cgal.org); you may redistribute it under
// the terms of the Q Public License version 1.0.
// See the file LICENSE.QPL distributed with CGAL.
//
// Licensees holding a valid commercial license may use this file in
// accordance with the commercial license agreement provided with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.2-branch/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Predicates_C2.h $
// $Id: Predicates_C2.h 28567 2006-02-16 14:30:13Z lsaboret $
// 
//
// Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>




#ifndef CGAL_SEGMENT_DELAUNAY_GRAPH_2_PREDICATES_C2_H
#define CGAL_SEGMENT_DELAUNAY_GRAPH_2_PREDICATES_C2_H

#include <CGAL/Segment_Delaunay_graph_2/Voronoi_vertex_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Compare_x_2.h>
#include <CGAL/Segment_Delaunay_graph_2/Compare_y_2.h>
#include <CGAL/Segment_Delaunay_graph_2/Are_parallel_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Are_same_points_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Are_same_segments_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Orientation_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Oriented_side_of_bisector_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Incircle_2.h>
#include <CGAL/Segment_Delaunay_graph_2/Finite_edge_interior_2.h>
#include <CGAL/Segment_Delaunay_graph_2/Infinite_edge_interior_2.h>
#include <CGAL/Segment_Delaunay_graph_2/Is_degenerate_edge_2.h>
#include <CGAL/Segment_Delaunay_graph_2/Arrangement_type_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Oriented_side_C2.h>

#endif // CGAL_SEGMENT_DELAUNAY_GRAPH_2_PREDICATES_C2_H

==> cgal_3.3.orig.tar.gz: CGAL-3.3/include/CGAL/Segment_Delaunay_graph_2/Predicates_C2.h <==
// Copyright (c) 2003,2004,2005,2006  INRIA Sophia-Antipolis (France) and
// Notre Dame University (U.S.A.).  All rights reserved.
//
// This file is part of CGAL (www.cgal.org); you may redistribute it under
// the terms of the Q Public License version 1.0.
// See the file LICENSE.QPL distributed with CGAL.
//
// Licensees holding a valid commercial license may use this file in
// accordance with the commercial license agreement provided with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// $URL: svn+ssh://scm.gforge.inria.fr/svn/cgal/branches/CGAL-3.3-branch/Segment_Delaunay_graph_2/include/CGAL/Segment_Delaunay_graph_2/Predicates_C2.h $
// $Id: Predicates_C2.h 32872 2006-08-01 12:38:07Z mkaravel $
// 
//
// Author(s)     : Menelaos Karavelas <mkaravel@cse.nd.edu>




#ifndef CGAL_SEGMENT_DELAUNAY_GRAPH_2_PREDICATES_C2_H
#define CGAL_SEGMENT_DELAUNAY_GRAPH_2_PREDICATES_C2_H

#include <CGAL/Segment_Delaunay_graph_2/Voronoi_vertex_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Compare_x_2.h>
#include <CGAL/Segment_Delaunay_graph_2/Compare_y_2.h>
#include <CGAL/Segment_Delaunay_graph_2/Are_parallel_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Are_same_points_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Are_same_segments_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Orientation_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Oriented_side_of_bisector_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Vertex_conflict_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Finite_edge_interior_conflict_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Infinite_edge_interior_conflict_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Is_degenerate_edge_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Arrangement_type_C2.h>
#include <CGAL/Segment_Delaunay_graph_2/Oriented_side_C2.h>

#endif // CGAL_SEGMENT_DELAUNAY_GRAPH_2_PREDICATES_C2_H
